########################################
 idf-build-apps |version| Documentation
########################################

This documentation is for idf-build-apps. idf-build-apps is a tool that allows developers to easily and reliably build applications for the ESP-IDF framework.

.. toctree::
   :maxdepth: 1
   :caption: Explanations

   explanations/config_rules
   explanations/find
   explanations/build
   explanations/dependency_driven_build

.. toctree::
   :maxdepth: 1
   :caption: Guides

   guides/1.x_to_2.x

.. toctree::
   :maxdepth: 1
   :caption: References

   references/manifest
   references/config_file
   references/cli
   references/api/modules.rst

.. toctree::
   :maxdepth: 1
   :caption: Others
   :glob:

   others/*
